==> department-2.3.0.tgz: package/es/modules/store/index.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } else { return Array.from(arr); } }

import { combineReducers, compose, createStore } from 'redux';
import { reducer as formReducer } from 'redux-form';
import { devToolsEnhancer } from 'redux-devtools-extension/developmentOnly';
import { notificationsReducer } from '../../components/Notifications';
import { modalsReducer } from '../../components/Modals';
import { authReducer } from '../../scenes/Auth';

// eslint-disable-next-line import/no-mutable-exports
export var store = void 0;

export function configureStore() {
  var reducers = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  var initialState = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
  var middleware = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : [];

  store = createStore(combineReducers(_extends({
    form: formReducer,
    auth: authReducer,
    notifications: notificationsReducer,
    modals: modalsReducer
  }, reducers)), initialState, compose.apply(undefined, _toConsumableArray(middleware).concat([devToolsEnhancer()])));

  return store;
}

==> department-2.5.0.tgz: package/es/modules/store/index.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } else { return Array.from(arr); } }

import { applyMiddleware, combineReducers, compose, createStore } from 'redux';
import { reducer as formReducer } from 'redux-form';
import { devToolsEnhancer } from 'redux-devtools-extension/developmentOnly';
import { notificationsReducer } from '../../components/Notifications';
import { modalsReducer } from '../../components/Modals';

// eslint-disable-next-line import/no-mutable-exports
export var store = void 0;

export function configureStore(apolloClient) {
  var reducers = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
  var initialState = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};
  var middleware = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : [];

  store = createStore(combineReducers(_extends({
    apollo: apolloClient.reducer(),
    form: formReducer,
    notifications: notificationsReducer,
    modals: modalsReducer
  }, reducers)), initialState, compose.apply(undefined, [applyMiddleware(apolloClient.middleware())].concat(_toConsumableArray(middleware), [devToolsEnhancer()])));

  return store;
}
